==> deepin-screenshot_4.0.11.orig.tar.gz: deepin-screenshot-4.0.11/translations/deepin-screenshot_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>select-area</source>
        <translation>alan-seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="951"/>
        <location filename="../mainwindow.cpp" line="953"/>
        <location filename="../mainwindow.cpp" line="1209"/>
        <location filename="../mainwindow.cpp" line="1212"/>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1228"/>
        <location filename="../mainwindow.cpp" line="1268"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <location filename="../mainwindow.cpp" line="1303"/>
        <location filename="../mainwindow.cpp" line="1306"/>
        <source>DeepinScreenshot</source>
        <translation>DeepinEkranGörüntüsü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="1321"/>
        <source>View</source>
        <translation>Göster</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="1341"/>
        <source>Picture has been saved to %1</source>
        <translation>Resim %1&apos;e kaydedildi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Picture has been saved to clipboard</source>
        <translation>Resim panoya kaydedildi</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="15"/>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="23"/>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="31"/>
        <source>Arrow</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="39"/>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="47"/>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="55"/>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="71"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="74"/>
        <source>Save to desktop</source>
        <translation>Masaüstüne kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="75"/>
        <source>Autosave</source>
        <translation>Otomatik kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="76"/>
        <source>Save to specified folder</source>
        <translation>Belirtilen klasöre kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="77"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="78"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Otomatik kaydet ve panoya kopyala</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="59"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>Deepin Ekran Görüntüsü %1 saniye sonra başlayacak</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="10"/>
        <source>Start/Screenshot</source>
        <translation>Başlat/Ekran Görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="11"/>
        <location filename="../utils/shortcut.cpp" line="22"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="12"/>
        <source>Painting</source>
        <translation>Boyama</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="13"/>
        <source>Size Adjustment</source>
        <translation>Boyut Ayarı</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="16"/>
        <source>Quick start</source>
        <translation>Hızlı başlangıç</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="17"/>
        <source>Full screenshot</source>
        <translation>Tam ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="18"/>
        <source>Delay screenshot</source>
        <translation>Gecikmeli ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="19"/>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="20"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="23"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="26"/>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="27"/>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="28"/>
        <source>Arrow</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Color</source>
        <translation>Renk</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="34"/>
        <source>Increase height up</source>
        <translation>Üst yüksekliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Increase height down</source>
        <translation>Alt yükselkliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Increase width left</source>
        <translation>Sol genişliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Increase width right</source>
        <translation>Sağ genişliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Decrease height up</source>
        <translation>Üst yükselkliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Decrease height down</source>
        <translation>Alt yükselkliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="40"/>
        <source>Decrease width left</source>
        <translation>Sol genişliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Decrease width right</source>
        <translation>Sağ genişliği azalt</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="377"/>
        <source>Save to desktop</source>
        <translation>Masaüstüne kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="383"/>
        <source>Autosave</source>
        <translation>Otomatik kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="389"/>
        <source>Save to specified folder</source>
        <translation>Belirtilen klasöre kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="395"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="400"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Otomatik kaydet ve panoya kopyala</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="405"/>
        <source>Low</source>
        <translation>Düşük</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="419"/>
        <source>High</source>
        <translation>Yüksek</translation>
    </message>
</context>
</TS>

==> deepin-screenshot_4.0.16.orig.tar.gz: deepin-screenshot-4.0.16/translations/deepin-screenshot_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>select-area</source>
        <translation>alan-seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="986"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1246"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1262"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1302"/>
        <location filename="../mainwindow.cpp" line="1305"/>
        <location filename="../mainwindow.cpp" line="1337"/>
        <location filename="../mainwindow.cpp" line="1340"/>
        <source>DeepinScreenshot</source>
        <translation>DeepinEkranGörüntüsü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1366"/>
        <source>View</source>
        <translation>Göster</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <location filename="../mainwindow.cpp" line="1386"/>
        <source>Picture has been saved to %1</source>
        <translation>Resim %1&apos;e kaydedildi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1360"/>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Picture has been saved to clipboard</source>
        <translation>Resim panoya kaydedildi</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="48"/>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="56"/>
        <source>Arrow</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="64"/>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="72"/>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="96"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Save to desktop</source>
        <translation>Masaüstüne kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="100"/>
        <source>Autosave</source>
        <translation>Otomatik kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="101"/>
        <source>Save to specified folder</source>
        <translation>Belirtilen klasöre kaydet</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="102"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="103"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Otomatik kaydet ve panoya kopyala</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="124"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="78"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>Deepin Ekran Görüntüsü %1 saniye sonra başlayacak</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Start/Screenshot</source>
        <translation>Başlat/Ekran Görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Painting</source>
        <translation>Boyama</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="32"/>
        <source>Size Adjustment</source>
        <translation>Boyut Ayarı</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Quick start</source>
        <translation>Hızlı başlangıç</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Full screenshot</source>
        <translation>Tam ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Delay screenshot</source>
        <translation>Gecikmeli ekran görüntüsü</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="42"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="45"/>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="46"/>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="47"/>
        <source>Arrow</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="48"/>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="49"/>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="50"/>
        <source>Color</source>
        <translation>Renk</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="53"/>
        <source>Increase height up</source>
        <translation>Üst yüksekliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="54"/>
        <source>Increase height down</source>
        <translation>Alt yükselkliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="55"/>
        <source>Increase width left</source>
        <translation>Sol genişliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="56"/>
        <source>Increase width right</source>
        <translation>Sağ genişliği arttır</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="57"/>
        <source>Decrease height up</source>
        <translation>Üst yükselkliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="58"/>
        <source>Decrease height down</source>
        <translation>Alt yükselkliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="59"/>
        <source>Decrease width left</source>
        <translation>Sol genişliği azalt</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="60"/>
        <source>Decrease width right</source>
        <translation>Sağ genişliği azalt</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="397"/>
        <source>Save to desktop</source>
        <translation>Masaüstüne kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="403"/>
        <source>Autosave</source>
        <translation>Otomatik kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="409"/>
        <source>Save to specified folder</source>
        <translation>Belirtilen klasöre kaydet</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="415"/>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="420"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Otomatik kaydet ve panoya kopyala</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="425"/>
        <source>Low</source>
        <translation>Düşük</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="439"/>
        <source>High</source>
        <translation>Yüksek</translation>
    </message>
</context>
</TS>
